#
# spec file for package eaglemode
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           eaglemode
Version:        0.96.0
Release:        2.1
Summary:        A zoomable user interface (ZUI) with file manager, file viewers, games, etc.
License:        GPL-3.0-only
Group:          Development/Tools/Other
URL:            https://eaglemode.sourceforge.net/
Source0:        https://downloads.sourceforge.net/%{name}/%{name}-%{version}/%{name}-%{version}.tar.bz2
Source1:        %{name}-icons.tar
Source2:        %{name}.desktop
Source3:        %{name}-rpmlintrc
Patch0:         01-eaglemode.patch
BuildRequires:  gcc-c++
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libtiff-devel
BuildRequires:  perl
Requires:       abiword
Requires:       xorg-x11
%if 0%{?sles_version}
BuildRequires:  gtk2-devel
%else
BuildRequires:  pkgconfig(gtk+-2.0)
%endif
%if 0%{?suse_version}
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  libpoppler-glib-devel
BuildRequires:  librsvg-devel
BuildRequires:  update-desktop-files
BuildRequires:  vlc-devel
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xproto)
BuildRequires:  pkgconfig(xt)
%endif
%if 0%{?mandriva_version}
BuildRequires:  libpoppler-glib-devel
BuildRequires:  librsvg2-devel
BuildRequires:  libxine-devel
BuildRequires:  x11-server-devel
%endif
%if 0%{?fedora_version}
BuildRequires:  libX11-devel
BuildRequires:  librsvg2-devel
BuildRequires:  poppler-glib-devel
BuildRequires:  xine-lib-devel
%endif
%if 0%{?suse_version}
Requires:       binutils
Requires:       bzip2
Requires:       gcc
Requires:       gedit
Requires:       ghostscript-x11
Requires:       gzip
Requires:       lzop
Requires:       perl
Requires:       tar
Requires:       texlive-bin-dvilj
Requires:       transfig
Requires:       unzip
Requires:       zip
# Remove when p7zip-full is in all products
%if 0%{?suse_version} > 1500
Requires:       p7zip-full
%else
Requires:       p7zip
%endif
%if 0%{?suse_version} > 1320
Requires:       xterm-bin
%else
Requires:       xterm
%endif
%endif

%description
Eagle Mode is an implementation of a futuristic style of man-machine
communication in which the user can visit almost everything simply by
zooming in. It has a file manager, file viewers and players for most
of the common file types, a chess game, a 3D mines game, a netwalk
game, a multi-function clock and some fractal fun, all integrated in
a virtual cosmos. That cosmos also provides a Linux kernel
configurator in form of a kernel patch.

It features a separate popup-zoomed control view, help texts in the
things they are describing, editable bookmarks, multiple input
methods, anti-aliased graphics, a virtually unlimited deep panel
tree, and a C++ API.

%prep
%autosetup -a 1 -p1

%build
# stupid build scripts don't allow passing custom flags
mkdir .bin
cat > .bin/gcc <<\EOF
#!/bin/sh
exec %{_bindir}/gcc %{optflags} "$@"
EOF
chmod +x .bin/gcc
PATH=$PWD/.bin:$PATH
perl make.pl build

%install
perl make.pl install dir=%{buildroot}/%{_libdir}/eaglemode

# install icons
for i in 16 24 32 48 ; do
    install -Dm 0644 icons/%{name}-${i}.png \
            %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/apps/%{name}.png
done

cd %{buildroot}/%{_libdir}/eaglemode
mkdir -p  ../../../%{_docdir}/eaglemode
cp -r doc ../../../%{_docdir}/eaglemode
mkdir -p ../../share/eaglemode
cp -r res ../../share/eaglemode
mkdir -p %{buildroot}%{_sysconfdir}/eaglemode
cp -r etc/* %{buildroot}%{_sysconfdir}/eaglemode
mkdir -p %{buildroot}%{_bindir}
cd %{buildroot}%{_bindir}
ln -s ../../%{_libdir}/eaglemode/eaglemode.sh eaglemode
mkdir -p %{buildroot}%{_prefix}/lib
cd %{buildroot}/%{_libdir}
ln -s eaglemode/lib/*.so .
mkdir -p %{buildroot}%{_includedir}
cd %{buildroot}%{_includedir}
ln -s ../../%{_libdir}/eaglemode/include/* .

# install Desktop file
install -Dm 0644 %{SOURCE2} %{buildroot}%{_datadir}/applications/%{name}.desktop

%if 0%{?suse_version}
    %suse_update_desktop_file %{name}
    %fdupes -s %{buildroot}%{_prefix}
%endif

%files
%{_bindir}/%{name}
%doc %{_docdir}/%{name}
%{_datadir}/%{name}
%{_libdir}/*.so
%{_libdir}/%{name}
%{_sysconfdir}/%{name}
%{_includedir}/*
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/applications/%{name}.desktop

%changelog
* Wed Apr 26 2023 Jan Engelhardt <jengelh@inai.de>
- Replace BuildRequire on xorg-x11-devel by pkgconfig(...)
* Sun Jan  8 2023 Dirk Müller <dmueller@suse.com>
- update to 0.96.0:
  * Added emStocks - a plugin for stock watchlists
  * Added undo/redo functions to editable text fields
  * Extended the graphics API to paint Bezier curves, arrows, and dashes
  * Added support for showing ICO files which are PNG compressed
  * Revised the emListBox API: Now the items have names
* Sun Dec  4 2022 Dirk Müller <dmueller@suse.com>
- update to 0.92.2:
  * Fixed DPI scaling on Windows.
  * Fixed changing of only letter case when renaming files on Windows.
  * Fixed useless re-rendering in emPdf.
  * Allowed to trigger radio boxes and check boxes by clicking on the text.
  * Adjusted some dialog sizes as well as click and expansion size thresholds to
    modern screen resolutions.
  * Updated emLKC to kernel 5.
  * Minor fixes.
  * Added a viewer for WebP image files.
  * Fixed focus problems with XWayland.
  * Minor fixes.
* Wed Sep 23 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.95
  * Added some interpolation algorithms for the zooming into photos, videos,
  * icons and other images. Now the user can choose (in the preferences) from:
  * Area Sampling, Bilinear, Bicubic, Lanczos, and Adaptive.
  * Accelerated graphics display by making use of the AVX2 CPU extension.
  * Extended the graphics API by a texture class which allows more flexible
  * filling of figures with colors and images.
  * Ported the audio/video player to Windows, based on the VLC library.
  * Switched from Xine to VLC also for other OSes because some tests showed
  that VLC is more crash-resistant against randomly corrupted files and
  thereby most likely more secure.
  * Completely removed support for outdated archive file formats to improve
  security and simplify maintenance: Goodbye to arc, arj, lha, rar, and zoo.
  Minor fixes and improvements.
* Mon Apr 15 2019 Jan Engelhardt <jengelh@inai.de>
- Trim marketing from description.
* Thu Apr 11 2019 Joop Boonen <joop.boonen@opensuse.org>
- Build version 0.94.1
  Changes:
  - Version 0.94.1
  * Improved video performance on multi-core CPUs a little.
  * Prohibited starting up after failure in creating initial bookmarks.
  * Reviewed and improved various details concerning protection against unwanted file system changes.
  * Colorized file manager command execution messages on Windows 10.
  - Version 0.94.0
  * Extended the internal font, mainly by Cyrillic and Greek characters.
  * Improved character code page support.
  * Added Clang support (compile command: perl make.pl build compiler=clang).
  * Minor fixes.
  - Version 0.93.2
  * Ported PDF, SVG, and PS viewers to Windows.
  * Minor fixes.
  - Version 0.93.1
  * Adapted minimally to new OS versions.
  * Ported time zones feature to Windows.
-  Cleaned Requires: *-devel up. As they are not needed most of them
  are auto detected
* Fri Jun 29 2018 kstreitova@suse.com
- require p7zip-full for TW as 7z binary needed by eaglemode was
  moved to this package (see bsc#899627 for more details about
  this change)
* Wed Oct 11 2017 joop.boonen@opensuse.org
- Update to 0.93.0, announce message:
  • Added autoplay function: Slideshow of picture files and playback of multiple audio/video files.
  • Minor fixes.
* Sat Jan  7 2017 nemysis@openSUSE.org
- Update to 0.92.0, announce message:
  • Parallelized painting for improved graphics performance on multi-core CPUs
  • Changed many virtual API methods to "const" (required for the above point,
    compiling old user code may fail, sorry, please adapt)
  • Minor fixes.
* Sun Jun 26 2016 nemysis@openSUSE.org
- Update to 0.91.0, announce message:
  * Fixed behavior on virtual desktops with multiple monitors.
  * Added saving and restoring of window geometry.
  * On X11, the fullscreen mode now goes via the window manager
  instead of switching to override-redirect mode.
  * On Windows, in the virtual cosmos, replaced all the static disk
  drive items and the home dir item by a single file system
  item which dynamically lists all available drives.
  * Minor fixes.
* Sat Apr 23 2016 nemysis@openSUSE.org
- Update to 0.90.0, announce message:
- Changes from Version 0.90.0
  * Added lots of icons to the control panel and gave it a new layout.
  * Reworked the graphic design of the toolkit elements (buttons, etc.).
  * Added new file manager themes: Glass, Card/*, and Night. Removed the Cloud theme.
  * Minor improvements and fixes.
- Changes from Version 0.89.2
  * Added API class emAvlTreeSet.
  * Moved emAvlTreeMap into an own header file.
  * Fixed the StrictRaster option of emRasterLayout.
  * Fixed configuration loading for minimum forward compatibility with the upcoming "design" version 0.90.0 (running <=0.89.1 after running 0.90.0 may crash).
  * Minor fixes.
- Remove not needed Requires for arc, lha and unarj
* Tue Aug 25 2015 nemysis@openSUSE.org
- Update to 0.89.1, announce message:
  * Fixed shortcuts for Windows systems where wsf files are not associated with wscript.
  * Multi-user installation of start menu and desktop icons on Windows.
  * Improved resolution of built-in font.
  * Minor fixes.
* Thu May 28 2015 nemysis@gmx.ch
- Use GenericName[en]=Eagle Mode instead of GenericName[en]=Eagle Modee
* Wed May 27 2015 nemysis@gmx.ch
- Update to 0.89.0, announce message:
- Changes fromVersion 0.89.0
  • Added new API classes: emListBox, emFileSelectionBox, emFileDialog,
    and emAnything.
  • Removed method emPanel::EnableAutoExpansion()
    (it's always "enabled" now).
  • Minor fixes and improvements.
- Changes from Version 0.88.0
  • Replaced API class emTiling by more specialized classes:
    emLinearLayout, emRasterLayout, and emPackLayout.
  • Accordingly replaced emGroup by emLinearGroup, emRasterGroup,
  and emPackGroup.
  • Fixed cropping of video frames.
  • Fixed launch feedback.
  • Minor fixes.
- Change Source0 to use Web URL
- Change Desktop entry
- Change icons, use eaglemode-icons.tar
- Add BuildRequires for hicolor-icon-theme
- Change Description
- Simplify installation handling
* Tue Jan  6 2015 p.drouand@gmail.com
- Update to version 0.87.0
  + Bug fix: The view often zoomed away unexpectedly from alternative
    file content panels (since version 0.86.0).
  + Reorganized the toolkit classes, renamed all "emTk*" to "em*".
  + Minor fixes.
- Changes from version 0.86.0
  + Added kinetic effects (inertia and friction) to zooming and scrolling
    by mouse and keyboard.
  + Added a magnetism which zooms and scrolls automatically for showing
    a content full-sized. (It gets active after zooming or scrolling by
    mouse, when a content is not to far from being shown full-sized.)
  + Added an acceleration effect to zooming by mouse wheel.
  + Added animations for logical position changes by keys and bookmarks.
  + Adapted emLKC to kernel 3.16 and higher.
  + Minor fixes and improvements.
- Changes from version 0.85.0
  + Fixed some bugs of the PDF viewer.
  + Adapted to Debian 7.
  + Adapted to xine-lib 1.2x.
  + Minor fixes.
* Wed Dec 17 2014 dimstar@opensuse.org
- On openSUSE > 13.2, xterm has been split into xterm-bin for the
  program and xterm for the app launcher. We only need the program,
  so conditionall Require xterm-bin.
* Sat Jun 29 2013 schwab@linux-m68k.org
- Force use of %%{optflags}
- Fix file list
* Mon Feb 11 2013 coolo@suse.com
- unrar is neither in FTP-repos nor on DVD, so better don't require it
* Mon Dec 24 2012 joop.boonen@opensuse.org
- Fixed sles build pkgconfig isn't supported by sles
* Wed Sep 19 2012 cfarrell@suse.com
- license update: GPL-3.0
  Many of the files are licensed under GPL-3.0 "only" (i.e. no mention of
  "or later")
* Mon Sep 17 2012 joop.boonen@opensuse.org
- Don't require arc, unarj and lha anymore as they don't
  exist in Factory and the are not used much anymore
* Thu Aug 30 2012 joop.boonen@opensuse.org
- Build version 0.84.0
- Added UHU-Linux patch so eaglemode is build for Factory
* Fri Jan  6 2012 joop.boonen@opensuse.org
- Reformated the spec file to meet the openSUSE standard
* Sat Nov 12 2011 joop.boonen@opensuse.org
- Build version 0.83.0
- Added missing buildreq
  libpoppler-glib-devel and gtk2-devel
* Sun Jul  3 2011 joop.boonen@opensuse.org
- Build version 0.82.0
* Wed May 11 2011 joop.boonen@opensuse.org
- Build version 0.81.0
* Tue Dec  7 2010 joop.boonen@opensuse.org
- Build version 0.80.0
* Mon Aug 23 2010 joop.boonen@opensuse.org
- Build version 0.79.0
* Fri Jul 23 2010 joop.boonen@opensuse.org
- etc files can now be found in /etc/eaglemode
  in stead of /etc/eaglemode/etc
- added export CFLAGS="$RPM_OPT_FLAGS"
- and export CXXFLAGS="$CFLAGS"
* Fri Jun 25 2010 joop.boonen@opensuse.org
- Build version 0.78.0
* Tue Feb  9 2010 joop.boonen@opensuse.org
- Build version 0.76.0
* Sat Jan  9 2010 joop.boonen@opensuse.org
- building with menu item
* Fri Jan  8 2010 joop.boonen@opensuse.org
- added all requirements according to te eagle mode webpage
* Sat Nov  7 2009 joop.boonen@opensuse.org
- Build version 0.75.1
